var system = require("../../../system");
var settings = require("../../../../config/settings");
const AppServiceBase = require("../../app.base");
//产品操作类
class UtilsUcommuneService extends AppServiceBase {
    constructor() {
        super();
        this.centerOrderUrl = settings.centerOrderUrl();
        this.centerChannelUrl = settings.centerChannelUrl();
        this.utilsAuthSve = system.getObject("service.utilsSve.utilsAuthSve");
        // this.alipay = settings.alipay();
        this.WXpay = settings.wxpay();
    }

  //--------------------------------优客工厂相关接口-start-----------------------------------------------------


    /**
     * 根据优客token获取用户信息，生成userPin返回前端
     * @param {*} pobj 
     * @param {*} actionBody userToken 为优客工厂的userToken
     */
    async getUserInfo(pobj, actionBody) {
        if (!actionBody.userToken) {
            return system.getResult(null, "actionBody.token can not be empty，100410");
        }
        var url = settings.ucommuneUrl() + "third/getUserInfo";    // 调用优客工场接口 获取用户信息
        // 拼接规则curl -k -H 'Content-type: application/json' -H 'authorization:{token}' -X POST {url} pobj作为发生错误时记录日志用
        let result = await this.restPostWithHAuthorizationUrl(pobj, actionBody.userToken, url);
        if(result.retCode == 0) {    // 0成功 1失败
            pobj.actionType = "getLoginByUserName";
            pobj.actionBody.channelUserId = result.data.nationalCode + result.data.mobile; // 即：86_18512345678
            pobj.actionBody.userpin = pobj.actionBody.userpin || this.getUUID();
            var tmpOpResult = await this.utilsAuthSve.getLoginByUserName(pobj, pobj.actionBody);
            if (tmpOpResult.status != 0 && tmpOpResult.status != 2060) {
                return tmpOpResult;
            }
            return system.getResultSuccess({ userpin: tmpOpResult.data.userpin })
        } else {
            // 获取用户信息失败
            return system.getResult(null, "Failed to get user information， 100420");
        }
    }
    /**
     * 优客调取订单列表用
     * @param {*} pobj 
     * @param {*} actionBody 
     */
    async ucommuneGetOrderList(pobj, actionBody) {
        var reqUrl = this.centerOrderUrl + "action/ucommuneOrder/springBoard";
        var result = await this.restPostUrl(pobj, reqUrl);
        return result;
    }

    /**
     * addOrder后进入支付页面获取支付金额 
     * @param {*} pobj 
     * @param {*} actionBody orderNo orderIndo订单号
     */
    async orderTotalSum(pobj, actionBody) {
        pobj.actionType = "getOrderDetails" // 获取订单详细信息 用来拼接字符串 totalsum为总金额，返回给前端
        var reqUrl = this.centerOrderUrl + "action/order/springBoard";
        var result = await this.restPostUrl(pobj, reqUrl);
        return result;
    }

    /**
     * 点击确认支付后返回拼接字符串
     * @param {*} pobj 
     * @param {*} actionBody orderNo orderIndo订单号
     */
    async orderConfirm(pobj, actionBody) {
        await this.orderConfirmValidate(pobj, actionBody);
        pobj.actionType = "getOrderDetails" // 获取订单详细信息 用来拼接字符串 totalsum为总金额，返回给前端
        var reqUrl = this.centerOrderUrl + "action/order/springBoard";
        var orderResult = await this.restPostUrl(pobj, reqUrl);
        console.log(orderResult)
        if(actionBody.payWay == 1) { // 支付宝
            const params = {
                bizContent: {
                  out_trade_no: '12312312321212', // 商户网站唯一订单号
                  subject: encodeURIComponent('苹果电脑'),//商品的标题/交易标题/订单标题/订单关键字等
                  total_amount: 0.2,//实际付款金额
                  body: encodeURIComponent('Mac Pro1'),//对一笔交易的具体描述信息。如果是多种商品，请将商品描述字符串累加传给body
                  product_code: 'QUICK_MSECURITY_PAY',
                  notifyUrl:this.centerChannelUrl + "orderNotify/aliPayNotify"
                }
              }
            let alipayResponse = await this.alipay.exec('alipay.trade.app.pay', params);
            console.log(alipayResponse);
        }
        if(actionBody.payWay == 3) { // 微信
            var wxpay = this.WXpay({
                appid: 'wx6f3ebe44defe336a',
                mch_id: '1232813602',
                partner_key: 'sinotone2014sinotone2014sinotone', //微信商户平台API密钥
                //pfx: fs.readFileSync('./wxpay_cert.p12'), //微信商户平台证书
              //pfx: "sinotone2014sinotone2014sinotone"
            });
            var out_trade_no='20160203'+Math.random().toString().substr(2, 10);
            wxpay.createUnifiedOrder({
            	body: '充值兑换宝币',
            	out_trade_no: out_trade_no,
            	total_fee: 1,
            	spbill_create_ip: '192.168.2.210',
            	notify_url: 'http://www.gongsibao.com',
            	trade_type: 'NATIVE',
            	product_id: '1234567890'
            }, function(err, result){
                console.log(result);
            })
        }
        return system.getResult(null, "actionBody.payWay is eoor values，100450");
    }

    /**
     * 点击确认支付后返回拼接字符串 orderConfirm 的验证数据方法
     * @param {*} pobj 
     * @param {*} actionBody orderNo orderIndo订单号
     */
    async orderConfirmValidate(pobj, actionBody) {
        if(!actionBody.orderNo) { // 订单号
            return system.getResult(null, "actionBody.orderNo can not be empty，100430");
        }
        if(!actionBody.payWay) { // 支付方式 1 支付宝 3微信
            return system.getResult(null, "actionBody.payWay can not be empty，100440");
        }
        if(actionBody.payWay != 1 || actionBody.payWay != 3) { // payway 非1非3 
            return system.getResult(null, "actionBody.payWay is eoor values，100450");
        }
    }

  //--------------------------------优客工厂相关接口--end----------------------------------------------------

}
module.exports = UtilsUcommuneService;

